@@ -1,4 +1,7 @@
 #![crate_type = "lib"]
+#![forbid(unsafe_code)]
+
+pub use traits::ToXMLElement;
 pub use xml::XML;
 pub use xmlelement::XMLElement;
 pub use xmlerror::{Result, XMLError};
@@ -7,6 +10,7 @@ pub use xmlversion::XMLVersion;
 use utils::escape_str;
 use xmlcontent::XMLElementContent;
 
+mod traits;
 mod utils;
 mod xml;
 mod xmlcontent;
